@@ -1,11 +1,14 @@
 package RSS::From::Forum::vBulletin;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
+use Log::Any::IfLOG qw($log);
 
 use Date::Parse;
-use Log::Any qw($log);
 use LWP::UserAgent;
 use Mojo::DOM;
 use POSIX;
@@ -14,8 +17,6 @@ use URI::URL;
 use Exporter::Lite;
 our @EXPORT_OK = qw(get_rss_from_forum);
 
-our $VERSION = '0.07'; # VERSION
-
 our %SPEC;
 
 sub _strip_session_param {
@@ -144,7 +145,7 @@ sub get_rss_from_forum {
 }
 
 1;
-#ABSTRACT: Get RSS page by parsing vBulletin forum display page
+# ABSTRACT: Generate an RSS page by parsing vBulletin forum display page
 
 __END__
 
@@ -154,11 +155,11 @@ __END__
 
 =head1 NAME
 
-RSS::From::Forum::vBulletin - Get RSS page by parsing vBulletin forum display page
+RSS::From::Forum::vBulletin - Generate an RSS page by parsing vBulletin forum display page
 
 =head1 VERSION
 
-This document describes version 0.07 of RSS::From::Forum::vBulletin (from Perl distribution RSS-From-Forum-vBulletin), released on 2014-08-16.
+This document describes version 0.08 of RSS::From::Forum::vBulletin (from Perl distribution RSS-From-Forum-vBulletin), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -168,16 +169,16 @@ This document describes version 0.07 of RSS::From::Forum::vBulletin (from Perl d
 
 =head1 FUNCTIONS
 
-None are exported, but they are exportable.
-
 
 =head2 get_rss_from_forum(%args) -> [status, msg, result, meta]
 
-Generate an RSS page by parsing vBulletin forum display page.
+{en_US Generate an RSS page by parsing vBulletin forum display page}.
 
+{en_US 
 Many vBulletin forums do not turn on RSS feeds. This function parses vBulletin
 forum display page and create a simple RSS page so you can subscribe to it using
 RSS.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -185,20 +186,22 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ua> => I<obj>
 
-Supply a custom LWP::UserAgent object.
+{en_US Supply a custom LWP::UserAgent object}.
 
+{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
+}
 
 =item * B<url>* => I<str>
 
-Forum URL (the forum display page).
+{en_US Forum URL (the forum display page)}.
 
+{en_US 
 Usually it's of the form: http://host/path/forumdisplay.php?f=XXX
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -208,7 +211,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -216,7 +219,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/RSS-From-F
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-RSS-From-Forum-vBulletin>.
+Source repository is at L<https://github.com/perlancar/perl-RSS-From-Forum-vBulletin>.
 
 =head1 BUGS
 
@@ -228,11 +231,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
